summaryrefslogtreecommitdiffstats
path: root/tools/designer/uic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/uic/form.cpp')
-rw-r--r--tools/designer/uic/form.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/designer/uic/form.cpp b/tools/designer/uic/form.cpp
index e185af6c..a2768de9 100644
--- a/tools/designer/uic/form.cpp
+++ b/tools/designer/uic/form.cpp
@@ -64,18 +64,18 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
r += l - 'a' + 10;
ba[ i ] = r;
}
// qUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;
ba[1] = ( length & 0x00ff0000 ) >> 16;
ba[2] = ( length & 0x0000ff00 ) >> 8;
ba[3] = ( length & 0x000000ff );
- TQByteArray baunzip = qUncompress( ba, baSize );
+ TQByteArray baunzip = tqUncompress( ba, baSize );
delete[] ba;
return baunzip;
}
-#if QT_VERSION >= 0x030900
+#if TQT_VERSION >= 0x030900
#error Add this functionality to TQDir (relativePathTo() maybe?) and \
remove it from here and from moc
#endif
@@ -373,8 +373,8 @@ void Uic::createFormDecl( const TQDomElement &e )
out << exportMacro << " ";
out << bareNameOfClass << " : public " << objClass << endl << "{" << endl;
- /* qmake ignore Q_OBJECT */
- out << " Q_OBJECT" << endl;
+ /* qmake ignore TQ_OBJECT */
+ out << " TQ_OBJECT" << endl;
out << endl;
out << "public:" << endl;
@@ -583,7 +583,7 @@ void Uic::createFormDecl( const TQDomElement &e )
registerLayouts( e );
out << endl;
-#if QT_VERSION >= 0x030900
+#if TQT_VERSION >= 0x030900
#error Make languageChange() a virtual protected non-slot member of TQWidget
#endif
@@ -64,18 +64,18 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
ba[ i ] = r;
}
- // qUncompress() expects the first 4 bytes to be the expected length of the
+ // tqUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;